@@ -36,16 +36,20 @@ use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{ COOKIE_CLASS MINIMUM_PERL };
 
-our $VERSION = '0.013';
+our $VERSION = '0.014';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
 sub perl_version_introduced {
     my ( $self ) = @_;
-    $self->content() =~ m/ \\ N /smx
-	and return '5.006';
-    return MINIMUM_PERL;
+    exists $self->{perl_version_introduced}
+	and return $self->{perl_version_introduced};
+    ( my $content = $self->content() ) =~ m/ \A \\ o /smx
+	and return ( $self->{perl_version_introduced} = '5.013003' );
+    $content =~ m/ \A \\ N /smx
+	and return ( $self->{perl_version_introduced} = '5.006' );
+    return ( $self->{perl_version_introduced} = MINIMUM_PERL );
 }
 
 # Some characters may or may not be literals depending on whether we are
@@ -129,16 +133,18 @@ The following is from perlop:
     # gets another dirty job.
     if ( $character eq '\\' ) {
 	if ( my $accept = $tokenizer->find_regexp(
-		qr{ \A \\ (?:
+		qr< \A \\ (?:
 		    [^\w\s] |		# delimiters/metas
 		    [tnrfae] |		# C-style escapes
-		    0 [01234567]* |	# octal
+		    0 [01234567]{0,2} |	# octal
+#		    [01234567]{1,3} |	# made from backref by lexer
 		    c [][[:alpha:]\@\\^_?] |	# control characters
 		    x (?: \{ [[:xdigit:]]* \} | [[:xdigit:]]{0,2} ) | # hex
+		    o [{] [01234567]+ [}] |	# octal as of 5.13.4
 		    N (?: \{ (?: [[:alpha:]] [\w\s:()-]* | # must begin w/ alpha
 			U [+] [[:xdigit:]]+ ) \} ) |	# unicode
 		    C (?: \d+ | \{ [^\}] \} )		# octets
-		) }smx ) ) {
+		) >smx ) ) {
 	    return $accept;
 	}
     }
@@ -178,6 +184,7 @@ because I don't understand the syntax.
 	'\\r' => ord "\r",
 	'\\f' => ord "\f",
 	'\\a' => ord "\a",
+	'\\b' => ord "\b",
 	'\\e' => ord "\e",
 	'\\c?' => ord "\c?",
 	'\\c@' => ord "\c@",
@@ -234,7 +241,7 @@ because I don't understand the syntax.
 	'\\cZ' => ord "\cZ",
 	'\\cz' => ord "\cZ",
 	'\\c[' => ord "\c[",
-	'\\c\\\\' => ord "\c\\",
+	'\\c\\\\' => ord "\c\\",	# " # Get Vim's head straight.
 	'\\c]' => ord "\c]",
 	'\\c^' => ord "\c^",
 	'\\c_' => ord "\c_",
@@ -268,6 +275,12 @@ because I don't understand the syntax.
 	    return;
 	}
 
+	if ( $indicator eq 'o' ) {
+	    $content =~ m/ \A \\ o [{] ( [01234567]+ ) [}] \z /smx
+		and return oct $1;
+	    return;
+	}
+
 	if ( $indicator eq 'N' ) {
 	    $content =~ m/ \A \\ N \{ ( [\w\s:]+ ) \} \z /smx
 		and return (
